"""Simple Class for handling W1 Sensors in a config file"""

from w1thermsensor import W1ThermSensor

class W1SensorConf:
    def __init__(self, configfile="/etc/w1.conf"):
        """read config from file"""
        self.adr={}
        self.configfile=configfile
        try:
            with open(self.configfile) as f:
                for line in f:
                    temp=line.split(":")
                    if(len(temp)==2):
                        self.adr[temp[0]]=int(temp[1])
        except (OSError, IOError):
            pass

        if(len(self.adr)>0):
            self.channels=self.adr.values()
            self.channels.sort()
        else:
            self.channels=[]

    def __get_next_channel_nr(self):
        ch=0
        self.channels
        for i in self.channels:
            if(i>ch):
                break
            ch=ch+1
        self.channels.append(ch)
        self.channels.sort()
        return ch
    
    def get_channel(self,sensor_id):
        if(sensor_id in self.adr):
            return(self.adr[sensor_id])
        return(-1)
    
    def save(self):
        f = open(self.configfile, 'w')
        for key, value in self.adr.iteritems():
            f.write("%s:%d\n" % (key,value))
        f.close()

    def update(self):
        old_adr=self.adr.copy()
        msg=""
        for sensor in W1ThermSensor.get_available_sensors([W1ThermSensor.THERM_SENSOR_DS18B20]):
            if(not (sensor.id in self.adr)):
                ch=self.__get_next_channel_nr()
                msg=msg+("UPDATE: New Sensor \"%s\" on Channel %d\n" % (sensor.id,ch))
                self.adr[sensor.id]=ch
            else:
                old_adr.pop(sensor.id)
         
        for key, value in old_adr.iteritems():
            msg=msg+("UPDATE: %s:%d does not respond - removing\n" % (key,value))
            self.adr.pop(key)
        if(len(msg)):
            self.save()
        return(msg)


